@@ -842,8 +842,8 @@ class ImageRegion3D(Scoord3DContentItem):
 
 class VolumeSurface(ContentSequence):
 
-    """Content sequence representing a volume surface in the the three-dimensional
-    patient/slide coordinate system in millimeter unit.
+    """Content sequence representing a volume surface in the the
+    three-dimensional patient/slide coordinate system in millimeter unit.
     """
 
     def __init__(
@@ -1268,7 +1268,7 @@ class FindingSite(CodeContentItem):
             modifier_item = CodeContentItem(
                 name=CodedConcept(
                     value='106233006',
-                    meaning='Topographical Modifier',
+                    meaning='Topographical modifier',
                     scheme_designator='SCT'
                 ),
                 value=topographical_modifier,
